@@ -21,9 +21,24 @@ def assignOrder(order):
 def GetMethodOrder(method):
     '''Returns the value of the .order property on the provided method. -1 if no order is assigned'''
     try:
-        return method.order
+        return int(method.order)
     except:
-        return -1
+        return int(-1)
+@register()
+
+def GetMethodName(method):
+    '''Returns the value of the .methodName property on the provided method. __name__ if no order is assigned'''
+    try:
+        return str(method.methodName)
+    except:
+        return str(method.__name__)
+    
+def GetMethodDescription(method):
+    '''Returns the value of the .methodDescription property on the provided method. __doc__ if no order is assigned'''
+    try:
+        return str(method.methodDescription)
+    except:
+        return str(method.__doc__)
     
 @register()
 def OutputMethodMetadata(method):
